@@ -5,10 +5,10 @@ Examples
 Apply a built-in theme
 
 >>> import pyvista
->>> pyvista.set_plot_theme('default')  # doctest:+SKIP
->>> pyvista.set_plot_theme('document')  # doctest:+SKIP
->>> pyvista.set_plot_theme('dark')  # doctest:+SKIP
->>> pyvista.set_plot_theme('paraview')  # doctest:+SKIP
+>>> pyvista.set_plot_theme('default')
+>>> pyvista.set_plot_theme('document')
+>>> pyvista.set_plot_theme('dark')
+>>> pyvista.set_plot_theme('paraview')
 
 Load a theme into pyvista
 
@@ -24,8 +24,8 @@ pyvista.
 >>> my_theme.font.title_size = 40
 >>> my_theme.cmap = 'jet'
 ...
->>> pyvista.global_theme.load_theme(my_theme)  # doctest:+SKIP
->>> pyvista.global_theme.font.size  # doctest:+SKIP
+>>> pyvista.global_theme.load_theme(my_theme)
+>>> pyvista.global_theme.font.size
 20
 
 """
@@ -107,19 +107,19 @@ def set_plot_theme(theme):
     Set to the default theme.
 
     >>> import pyvista
-    >>> pyvista.set_plot_theme('default')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('default')
 
     Set to the document theme.
 
-    >>> pyvista.set_plot_theme('document')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('document')
 
     Set to the dark theme.
 
-    >>> pyvista.set_plot_theme('dark')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('dark')
 
     Set to the ParaView theme.
 
-    >>> pyvista.set_plot_theme('paraview')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('paraview')
 
     """
     import pyvista
@@ -216,9 +216,9 @@ class _DepthPeelingConfig(_ThemeConfig):
     Set global depth peeling parameters.
 
     >>> import pyvista
-    >>> pyvista.global_theme.depth_peeling.number_of_peels = 1  # doctest:+SKIP
-    >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0  # doctest:+SKIP
-    >>> pyvista.global_theme.depth_peeling.enabled = True  # doctest:+SKIP
+    >>> pyvista.global_theme.depth_peeling.number_of_peels = 1
+    >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0
+    >>> pyvista.global_theme.depth_peeling.enabled = True
 
     """
 
@@ -236,7 +236,7 @@ class _DepthPeelingConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.depth_peeling.number_of_peels = 1  # doctest:+SKIP
+        >>> pyvista.global_theme.depth_peeling.number_of_peels = 1
 
         """
         return self._number_of_peels
@@ -252,7 +252,7 @@ class _DepthPeelingConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0  # doctest:+SKIP
+        >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0
 
         """
         return self._occlusion_ratio
@@ -268,7 +268,7 @@ class _DepthPeelingConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.depth_peeling.enabled = True  # doctest:+SKIP
+        >>> pyvista.global_theme.depth_peeling.enabled = True
 
         """
         return self._enabled
@@ -298,9 +298,9 @@ class _SilhouetteConfig(_ThemeConfig):
     Set global silhouette parameters.
 
     >>> import pyvista
-    >>> pyvista.global_theme.silhouette.color = 'grey'  # doctest:+SKIP
-    >>> pyvista.global_theme.silhouette.line_width = 2  # doctest:+SKIP
-    >>> pyvista.global_theme.silhouette.feature_angle = 20  # doctest:+SKIP
+    >>> pyvista.global_theme.silhouette.color = 'grey'
+    >>> pyvista.global_theme.silhouette.line_width = 2
+    >>> pyvista.global_theme.silhouette.feature_angle = 20
 
     """
 
@@ -320,7 +320,7 @@ class _SilhouetteConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.color = 'red'  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.color = 'red'
 
         """
         return self._color
@@ -336,7 +336,7 @@ class _SilhouetteConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.line_width = 2.0  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.line_width = 2.0
 
         """
         return self._line_width
@@ -352,7 +352,7 @@ class _SilhouetteConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.opacity = 1.0  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.opacity = 1.0
 
         """
         return self._opacity
@@ -369,7 +369,7 @@ class _SilhouetteConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.feature_angle = 20.0  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.feature_angle = 20.0
 
         """
         return self._feature_angle
@@ -387,7 +387,7 @@ class _SilhouetteConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.decimate = 0.9  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.decimate = 0.9
 
         """
         return self._decimate
@@ -420,7 +420,7 @@ class _ColorbarConfig(_ThemeConfig):
     Set the colorbar width.
 
     >>> import pyvista
-    >>> pyvista.global_theme.colorbar_horizontal.width = 0.2  # doctest:+SKIP
+    >>> pyvista.global_theme.colorbar_horizontal.width = 0.2
 
     """
 
@@ -439,7 +439,7 @@ class _ColorbarConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_horizontal.width = 0.2  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.width = 0.2
 
         """
         return self._width
@@ -455,7 +455,7 @@ class _ColorbarConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_horizontal.height = 0.2  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.height = 0.2
 
         """
         return self._height
@@ -471,7 +471,7 @@ class _ColorbarConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_horizontal.position_x = 0.2  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.position_x = 0.2
 
         """
         return self._position_x
@@ -487,7 +487,7 @@ class _ColorbarConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_horizontal.position_y = 0.2  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.position_y = 0.2
 
         """
         return self._position_y
@@ -519,15 +519,15 @@ class _AxesConfig(_ThemeConfig):
     Set the x axis color to black.
 
     >>> import pyvista
-    >>> pyvista.global_theme.axes.x_color = 'black'  # doctest:+SKIP
+    >>> pyvista.global_theme.axes.x_color = 'black'
 
     Show axes by default.
 
-    >>> pyvista.global_theme.axes.show = True  # doctest:+SKIP
+    >>> pyvista.global_theme.axes.show = True
 
     Use the ``vtk.vtkCubeAxesActor``.
 
-    >>> pyvista.global_theme.axes.box = True  # doctest:+SKIP
+    >>> pyvista.global_theme.axes.box = True
 
     """
 
@@ -562,7 +562,7 @@ class _AxesConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.axes.x_color = 'red'  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.x_color = 'red'
         """
         return self._x_color
 
@@ -577,7 +577,7 @@ class _AxesConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.axes.y_color = 'red'  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.y_color = 'red'
         """
         return self._y_color
 
@@ -592,7 +592,7 @@ class _AxesConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.axes.z_color = 'red'  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.z_color = 'red'
         """
         return self._z_color
 
@@ -607,7 +607,7 @@ class _AxesConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.axes.box = True  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.box = True
 
         """
         return self._box
@@ -625,7 +625,7 @@ class _AxesConfig(_ThemeConfig):
         Hide the axes by default.
 
         >>> import pyvista
-        >>> pyvista.global_theme.axes.show = False  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.show = False
 
         """
         return self._show
@@ -644,27 +644,27 @@ class _Font(_ThemeConfig):
     'arial', 'courier', or 'times'.
 
     >>> import pyvista
-    >>> pyvista.global_theme.font.family = 'arial'  # doctest:+SKIP
+    >>> pyvista.global_theme.font.family = 'arial'
 
     Set the default font size to 20.
 
-    >>> pyvista.global_theme.font.size = 20  # doctest:+SKIP
+    >>> pyvista.global_theme.font.size = 20
 
     Set the default title size to 40
 
-    >>> pyvista.global_theme.font.title_size = 40  # doctest:+SKIP
+    >>> pyvista.global_theme.font.title_size = 40
 
     Set the default label size to 10
 
-    >>> pyvista.global_theme.font.label_size = 10  # doctest:+SKIP
+    >>> pyvista.global_theme.font.label_size = 10
 
     Set the default text color to 'grey'
 
-    >>> pyvista.global_theme.font.color = 'grey'  # doctest:+SKIP
+    >>> pyvista.global_theme.font.color = 'grey'
 
     Set the string formatter used to format numerical data to '%.6e'
 
-    >>> pyvista.global_theme.font.fmt = '%.6e'  # doctest:+SKIP
+    >>> pyvista.global_theme.font.fmt = '%.6e'
 
     """
 
@@ -709,7 +709,7 @@ class _Font(_ThemeConfig):
         Set the default global font family to 'courier'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.font.family = 'courier'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.family = 'courier'
 
         """
         return self._family
@@ -726,7 +726,7 @@ class _Font(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.font.size = 20  # doctest:+SKIP
+        >>> pyvista.global_theme.font.size = 20
 
         """
         return self._size
@@ -744,7 +744,7 @@ class _Font(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.font.title_size = 20  # doctest:+SKIP
+        >>> pyvista.global_theme.font.title_size = 20
         """
         return self._title_size
 
@@ -764,7 +764,7 @@ class _Font(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.font.label_size = 20  # doctest:+SKIP
+        >>> pyvista.global_theme.font.label_size = 20
         """
         return self._label_size
 
@@ -782,7 +782,7 @@ class _Font(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.font.color = 'black'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.color = 'black'
         """
         return self._color
 
@@ -799,7 +799,7 @@ class _Font(_ThemeConfig):
         Set the string formatter used to format numerical data to '%.6e'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.font.fmt = '%.6e'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.fmt = '%.6e'
 
         """
         return self._fmt
@@ -852,7 +852,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.cap_width = 0.02  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.cap_width = 0.02
 
         """
         return self._cap_width
@@ -868,7 +868,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.cap_length = 0.01  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.cap_length = 0.01
 
         """
         return self._cap_length
@@ -884,7 +884,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.cap_opacity = 1.0  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.cap_opacity = 1.0
 
         """
         return self._cap_opacity
@@ -900,7 +900,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.tube_color = 'black'  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.tube_color = 'black'
         """
         return self._tube_color
 
@@ -915,7 +915,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.tube_width = 0.005  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.tube_width = 0.005
 
         """
         return self._tube_width
@@ -931,7 +931,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.slider_color = 'grey'  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.slider_color = 'grey'
 
         """
         return self._slider_color
@@ -947,7 +947,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.slider_width = 0.04  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.slider_width = 0.04
 
         """
         return self._slider_width
@@ -963,7 +963,7 @@ class _SliderStyleConfig(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.slider_styles.modern.slider_length = 0.02  # doctest:+SKIP
+        >>> pyvista.global_theme.slider_styles.modern.slider_length = 0.02
 
         """
         return self._slider_length
@@ -1092,18 +1092,18 @@ class DefaultTheme(_ThemeConfig):
     Change the global default background color to white.
 
     >>> import pyvista
-    >>> pyvista.global_theme.color = 'white'  # doctest:+SKIP
+    >>> pyvista.global_theme.color = 'white'
 
     Show edges by default.
 
-    >>> pyvista.global_theme.show_edges = True  # doctest:+SKIP
+    >>> pyvista.global_theme.show_edges = True
 
     Create a new theme from the default theme and apply it globally.
 
     >>> my_theme = pyvista.themes.DefaultTheme()
     >>> my_theme.color = 'red'
     >>> my_theme.background = 'white'
-    >>> pyvista.global_theme.load_theme(my_theme)  # doctest:+SKIP
+    >>> pyvista.global_theme.load_theme(my_theme)
 
     """
 
@@ -1145,6 +1145,8 @@ class DefaultTheme(_ThemeConfig):
         '_hidden_line_removal',
         '_antialiasing',
         '_enable_camera_orientation_widget',
+        '_split_sharp_edges',
+        '_sharp_edges_feature_angle',
     ]
 
     def __init__(self):
@@ -1188,6 +1190,8 @@ class DefaultTheme(_ThemeConfig):
         self._transparent_background = False
         self._title = 'PyVista'
         self._axes = _AxesConfig()
+        self._split_sharp_edges = False
+        self._sharp_edges_feature_angle = 30.0
 
         # Grab system flag for anti-aliasing
         try:
@@ -1227,8 +1231,8 @@ class DefaultTheme(_ThemeConfig):
         Enable hidden line removal.
 
         >>> import pyvista
-        >>> pyvista.global_theme.hidden_line_removal = True  # doctest:+SKIP
-        >>> pyvista.global_theme.hidden_line_removal  # doctest:+SKIP
+        >>> pyvista.global_theme.hidden_line_removal = True
+        >>> pyvista.global_theme.hidden_line_removal
         True
 
         """
@@ -1247,7 +1251,7 @@ class DefaultTheme(_ThemeConfig):
         Disable returning camera position by ``show`` and ``plot`` methods.
 
         >>> import pyvista
-        >>> pyvista.global_theme.return_cpos = False  # doctest:+SKIP
+        >>> pyvista.global_theme.return_cpos = False
         """
 
     @return_cpos.setter
@@ -1263,7 +1267,7 @@ class DefaultTheme(_ThemeConfig):
         Set the default global background of all plots to white.
 
         >>> import pyvista
-        >>> pyvista.global_theme.background = 'white'  # doctest:+SKIP
+        >>> pyvista.global_theme.background = 'white'
         """
         return self._background
 
@@ -1317,24 +1321,24 @@ class DefaultTheme(_ThemeConfig):
         Enable the pythreejs backend.
 
         >>> import pyvista as pv
-        >>> pv.set_jupyter_backend('pythreejs')  # doctest:+SKIP
+        >>> pv.set_jupyter_backend('pythreejs')
 
         Enable the ipygany backend.
 
         >>> import pyvista as pv
-        >>> pv.set_jupyter_backend('ipygany')  # doctest:+SKIP
+        >>> pv.set_jupyter_backend('ipygany')
 
         Enable the panel backend.
 
-        >>> pv.set_jupyter_backend('panel')  # doctest:+SKIP
+        >>> pv.set_jupyter_backend('panel')
 
         Enable the ipyvtklink backend.
 
-        >>> pv.set_jupyter_backend('ipyvtklink')  # doctest:+SKIP
+        >>> pv.set_jupyter_backend('ipyvtklink')
 
         Just show static images.
 
-        >>> pv.set_jupyter_backend('static')  # doctest:+SKIP
+        >>> pv.set_jupyter_backend('static')
 
         Disable all plotting within JupyterLab and display using a
         standard desktop VTK render window.
@@ -1360,7 +1364,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.auto_close = False  # doctest:+SKIP
+        >>> pyvista.global_theme.auto_close = False
 
         """
         return self._auto_close
@@ -1378,7 +1382,7 @@ class DefaultTheme(_ThemeConfig):
         Set windows to be full screen by default.
 
         >>> import pyvista
-        >>> pyvista.global_theme.full_screen = True  # doctest:+SKIP
+        >>> pyvista.global_theme.full_screen = True
         """
         return self._full_screen
 
@@ -1393,8 +1397,8 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.enable_camera_orientation_widget = True  # doctest:+SKIP
-        >>> pyvista.global_theme.enable_camera_orientation_widget  # doctest:+SKIP
+        >>> pyvista.global_theme.enable_camera_orientation_widget = True
+        >>> pyvista.global_theme.enable_camera_orientation_widget
         True
 
         """
@@ -1413,16 +1417,16 @@ class DefaultTheme(_ThemeConfig):
         Set both the position and view of the camera.
 
         >>> import pyvista
-        >>> pyvista.global_theme.camera = {'position': [1, 1, 1],  # doctest:+SKIP
-        ...                                'viewup': [0, 0, 1]}  # doctest:+SKIP
+        >>> pyvista.global_theme.camera = {'position': [1, 1, 1],
+        ...                                'viewup': [0, 0, 1]}
 
         Set the default position of the camera.
 
-        >>> pyvista.global_theme.camera['position'] = [1, 1, 1]  # doctest:+SKIP
+        >>> pyvista.global_theme.camera['position'] = [1, 1, 1]
 
         Set the default view of the camera.
 
-        >>> pyvista.global_theme.camera['viewup'] = [0, 0, 1]  # doctest:+SKIP
+        >>> pyvista.global_theme.camera['viewup'] = [0, 0, 1]
 
         """
         return self._camera
@@ -1452,7 +1456,7 @@ class DefaultTheme(_ThemeConfig):
         Disable all jupyter notebook plotting.
 
         >>> import pyvista
-        >>> pyvista.global_theme.notebook = False  # doctest:+SKIP
+        >>> pyvista.global_theme.notebook = False
 
         """
         return self._notebook
@@ -1470,7 +1474,7 @@ class DefaultTheme(_ThemeConfig):
         Set window size to ``[400, 400]``.
 
         >>> import pyvista
-        >>> pyvista.global_theme.window_size = [400, 400]  # doctest:+SKIP
+        >>> pyvista.global_theme.window_size = [400, 400]
 
         """
         return self._window_size
@@ -1496,27 +1500,27 @@ class DefaultTheme(_ThemeConfig):
         'arial', 'courier', or 'times'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.font.family = 'arial'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.family = 'arial'
 
         Set the default font size to 20.
 
-        >>> pyvista.global_theme.font.size = 20  # doctest:+SKIP
+        >>> pyvista.global_theme.font.size = 20
 
         Set the default title size to 40.
 
-        >>> pyvista.global_theme.font.title_size = 40  # doctest:+SKIP
+        >>> pyvista.global_theme.font.title_size = 40
 
         Set the default label size to 10.
 
-        >>> pyvista.global_theme.font.label_size = 10  # doctest:+SKIP
+        >>> pyvista.global_theme.font.label_size = 10
 
         Set the default text color to 'grey'.
 
-        >>> pyvista.global_theme.font.color = 'grey'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.color = 'grey'
 
         String formatter used to format numerical data to '%.6e'.
 
-        >>> pyvista.global_theme.font.fmt = '%.6e'  # doctest:+SKIP
+        >>> pyvista.global_theme.font.fmt = '%.6e'
 
         """
         return self._font
@@ -1545,15 +1549,22 @@ class DefaultTheme(_ThemeConfig):
         Set the default global colormap to 'jet'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.cmap = 'jet'  # doctest:+SKIP
+        >>> pyvista.global_theme.cmap = 'jet'
 
         """
         return self._cmap
 
     @cmap.setter
     def cmap(self, cmap):
-        get_cmap_safe(cmap)  # for validation
-        self._cmap = cmap
+        try:
+            get_cmap_safe(cmap)  # for validation
+            self._cmap = cmap
+        except ImportError:  # pragma: no cover
+            warnings.warn(
+                'Unable to set a default theme colormap without matplotlib. '
+                'The builtin VTK "jet" colormap will be used.'
+            )
+            self._cmap = None
 
     @property
     def color(self) -> Color:
@@ -1574,7 +1585,7 @@ class DefaultTheme(_ThemeConfig):
         Set the default mesh color to 'red'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.color = 'red'  # doctest:+SKIP
+        >>> pyvista.global_theme.color = 'red'
 
         """
         return self._color
@@ -1592,7 +1603,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.nan_color = 'darkgray'  # doctest:+SKIP
+        >>> pyvista.global_theme.nan_color = 'darkgray'
 
         """
         return self._nan_color
@@ -1610,7 +1621,7 @@ class DefaultTheme(_ThemeConfig):
         Set the global edge color to 'blue'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.edge_color = 'blue'  # doctest:+SKIP
+        >>> pyvista.global_theme.edge_color = 'blue'
 
         """
         return self._edge_color
@@ -1626,7 +1637,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.outline_color = 'white'  # doctest:+SKIP
+        >>> pyvista.global_theme.outline_color = 'white'
 
         """
         return self._outline_color
@@ -1642,7 +1653,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.floor_color = 'black'  # doctest:+SKIP
+        >>> pyvista.global_theme.floor_color = 'black'
 
         """
         return self._floor_color
@@ -1660,7 +1671,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_orientation = 'horizontal'  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_orientation = 'horizontal'
 
         """
         return self._colorbar_orientation
@@ -1680,11 +1691,11 @@ class DefaultTheme(_ThemeConfig):
         Set the default horizontal colorbar width to 0.6.
 
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_horizontal.width = 0.6  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.width = 0.6
 
         Set the default horizontal colorbar height to 0.2.
 
-        >>> pyvista.global_theme.colorbar_horizontal.height = 0.2  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_horizontal.height = 0.2
 
         """
         return self._colorbar_horizontal
@@ -1704,12 +1715,12 @@ class DefaultTheme(_ThemeConfig):
         Set the default colorbar width to 0.45.
 
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_vertical.width = 0.45  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_vertical.width = 0.45
 
         Set the default colorbar height to 0.8.
 
         >>> import pyvista
-        >>> pyvista.global_theme.colorbar_vertical.height = 0.8  # doctest:+SKIP
+        >>> pyvista.global_theme.colorbar_vertical.height = 0.8
 
         """
         return self._colorbar_vertical
@@ -1729,7 +1740,7 @@ class DefaultTheme(_ThemeConfig):
         Show the scalar bar by default when scalars are available.
 
         >>> import pyvista
-        >>> pyvista.global_theme.show_scalar_bar = True  # doctest:+SKIP
+        >>> pyvista.global_theme.show_scalar_bar = True
 
         """
         return self._show_scalar_bar
@@ -1747,7 +1758,7 @@ class DefaultTheme(_ThemeConfig):
         Show edges globally by default.
 
         >>> import pyvista
-        >>> pyvista.global_theme.show_edges = True  # doctest:+SKIP
+        >>> pyvista.global_theme.show_edges = True
 
         """
         return self._show_edges
@@ -1765,7 +1776,7 @@ class DefaultTheme(_ThemeConfig):
         Disable lighting globally.
 
         >>> import pyvista
-        >>> pyvista.global_theme.lighting = False  # doctest:+SKIP
+        >>> pyvista.global_theme.lighting = False
         """
         return self._lighting
 
@@ -1782,7 +1793,7 @@ class DefaultTheme(_ThemeConfig):
         Make all plots non-interactive globally.
 
         >>> import pyvista
-        >>> pyvista.global_theme.interactive = False  # doctest:+SKIP
+        >>> pyvista.global_theme.interactive = False
         """
         return self._interactive
 
@@ -1799,7 +1810,7 @@ class DefaultTheme(_ThemeConfig):
         Render points as spheres by default globally.
 
         >>> import pyvista
-        >>> pyvista.global_theme.render_points_as_spheres = True  # doctest:+SKIP
+        >>> pyvista.global_theme.render_points_as_spheres = True
         """
         return self._render_points_as_spheres
 
@@ -1816,7 +1827,7 @@ class DefaultTheme(_ThemeConfig):
         Set transparent_background globally to ``True``.
 
         >>> import pyvista
-        >>> pyvista.global_theme.transparent_background = True  # doctest:+SKIP
+        >>> pyvista.global_theme.transparent_background = True
 
         """
         return self._transparent_background
@@ -1836,7 +1847,7 @@ class DefaultTheme(_ThemeConfig):
         Set title globally to 'plot'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.title = 'plot'  # doctest:+SKIP
+        >>> pyvista.global_theme.title = 'plot'
 
         """
         return self._title
@@ -1854,8 +1865,8 @@ class DefaultTheme(_ThemeConfig):
         Enable anti-aliasing in the global theme.
 
         >>> import pyvista
-        >>> pyvista.global_theme.antialiasing = True  # doctest:+SKIP
-        >>> pyvista.global_theme.antialiasing  # doctest:+SKIP
+        >>> pyvista.global_theme.antialiasing = True
+        >>> pyvista.global_theme.antialiasing
         True
 
         """
@@ -1876,7 +1887,7 @@ class DefaultTheme(_ThemeConfig):
         Set the default number of multisamples to 2.
 
         >>> import pyvista
-        >>> pyvista.global_theme.multi_samples = 2  # doctest:+SKIP
+        >>> pyvista.global_theme.multi_samples = 2
 
         """
         return self._multi_samples
@@ -1895,7 +1906,7 @@ class DefaultTheme(_ThemeConfig):
         middle of the window).
 
         >>> import pyvista
-        >>> pyvista.global_theme.multi_rendering_splitting_position = 0.5  # doctest:+SKIP
+        >>> pyvista.global_theme.multi_rendering_splitting_position = 0.5
 
         """
         return self._multi_rendering_splitting_position
@@ -1921,7 +1932,7 @@ class DefaultTheme(_ThemeConfig):
         Set default volume mapper globally to 'gpu'.
 
         >>> import pyvista
-        >>> pyvista.global_theme.volume_mapper = 'gpu'  # doctest:+SKIP
+        >>> pyvista.global_theme.volume_mapper = 'gpu'
 
         """
         return self._volume_mapper
@@ -1946,7 +1957,7 @@ class DefaultTheme(_ThemeConfig):
         Set the global smooth_shading parameter default to ``True``.
 
         >>> import pyvista
-        >>> pyvista.global_theme.smooth_shading = True  # doctest:+SKIP
+        >>> pyvista.global_theme.smooth_shading = True
 
         """
         return self._smooth_shading
@@ -1965,9 +1976,9 @@ class DefaultTheme(_ThemeConfig):
         with 8 peels.
 
         >>> import pyvista
-        >>> pyvista.global_theme.depth_peeling.number_of_peels = 8  # doctest:+SKIP
-        >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0  # doctest:+SKIP
-        >>> pyvista.global_theme.depth_peeling.enabled = True  # doctest:+SKIP
+        >>> pyvista.global_theme.depth_peeling.number_of_peels = 8
+        >>> pyvista.global_theme.depth_peeling.occlusion_ratio = 0.0
+        >>> pyvista.global_theme.depth_peeling.enabled = True
 
         """
         return self._depth_peeling
@@ -1987,9 +1998,9 @@ class DefaultTheme(_ThemeConfig):
         Set parameters of the silhouette.
 
         >>> import pyvista
-        >>> pyvista.global_theme.silhouette.color = 'grey'  # doctest:+SKIP
-        >>> pyvista.global_theme.silhouette.line_width = 2.0  # doctest:+SKIP
-        >>> pyvista.global_theme.silhouette.feature_angle = 20  # doctest:+SKIP
+        >>> pyvista.global_theme.silhouette.color = 'grey'
+        >>> pyvista.global_theme.silhouette.line_width = 2.0
+        >>> pyvista.global_theme.silhouette.feature_angle = 20
 
         """
         return self._silhouette
@@ -2020,15 +2031,15 @@ class DefaultTheme(_ThemeConfig):
         Set the x axis color to black.
 
         >>> import pyvista
-        >>> pyvista.global_theme.axes.x_color = 'black'  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.x_color = 'black'
 
         Show axes by default.
 
-        >>> pyvista.global_theme.axes.show = True  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.show = True
 
         Use the ``vtk.vtkCubeAxesActor``.
 
-        >>> pyvista.global_theme.axes.box = True  # doctest:+SKIP
+        >>> pyvista.global_theme.axes.box = True
 
         """
         return self._axes
@@ -2045,7 +2056,7 @@ class DefaultTheme(_ThemeConfig):
         Examples
         --------
         >>> import pyvista
-        >>> pyvista.global_theme.restore_defaults()  # doctest:+SKIP
+        >>> pyvista.global_theme.restore_defaults()
 
         """
         self.__init__()
@@ -2090,6 +2101,8 @@ class DefaultTheme(_ThemeConfig):
             'Return Camera Position': 'return_cpos',
             'Hidden Line Removal': 'hidden_line_removal',
             'Anti-Aliasing': '_antialiasing',
+            'Split sharp edges': '_split_sharp_edges',
+            'Sharp edges feat. angle': '_sharp_edges_feature_angle',
         }
         for name, attr in parm.items():
             setting = getattr(self, attr)
@@ -2126,8 +2139,8 @@ class DefaultTheme(_ThemeConfig):
         >>> my_theme.font.title_size = 40
         >>> my_theme.cmap = 'jet'
         ...
-        >>> pyvista.global_theme.load_theme(my_theme)  # doctest:+SKIP
-        >>> pyvista.global_theme.font.size  # doctest:+SKIP
+        >>> pyvista.global_theme.load_theme(my_theme)
+        >>> pyvista.global_theme.font.size
         20
 
         Create a custom theme from the dark theme and load it into
@@ -2136,8 +2149,8 @@ class DefaultTheme(_ThemeConfig):
         >>> from pyvista.themes import DarkTheme
         >>> my_theme = DarkTheme()
         >>> my_theme.show_edges = True
-        >>> pyvista.global_theme.load_theme(my_theme)  # doctest:+SKIP
-        >>> pyvista.global_theme.show_edges  # doctest:+SKIP
+        >>> pyvista.global_theme.load_theme(my_theme)
+        >>> pyvista.global_theme.show_edges
         True
 
         """
@@ -2198,6 +2211,57 @@ class DefaultTheme(_ThemeConfig):
         else:
             self.jupyter_backend = 'static'
 
+    @property
+    def split_sharp_edges(self) -> bool:
+        """Set or return splitting sharp edges.
+
+        See :ref:`shading_example` for an example showing split sharp edges.
+
+        Examples
+        --------
+        Enable the splitting of sharp edges globally.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.split_sharp_edges = True
+        >>> pyvista.global_theme.split_sharp_edges
+        True
+
+        Disable the splitting of sharp edges globally.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.split_sharp_edges = False
+        >>> pyvista.global_theme.split_sharp_edges
+        False
+
+        """
+        return self._split_sharp_edges
+
+    @split_sharp_edges.setter
+    def split_sharp_edges(self, value: bool):
+        self._split_sharp_edges = value
+
+    @property
+    def sharp_edges_feature_angle(self) -> float:
+        """Set or return the angle of the sharp edges feature angle.
+
+        See :ref:`shading_example` for an example showing split sharp edges.
+
+        Examples
+        --------
+        Change the sharp edges feature angle to 45 degrees.
+
+        >>> import pyvista
+        >>> pyvista.global_theme.sharp_edges_feature_angle = 45.0
+        >>> pyvista.global_theme.sharp_edges_feature_angle
+        45.0
+
+        """
+        return self._sharp_edges_feature_angle
+
+    @sharp_edges_feature_angle.setter
+    def sharp_edges_feature_angle(self, value: float):
+        self._sharp_edges_feature_angle = float(value)
+
 
 class DarkTheme(DefaultTheme):
     """Dark mode theme.
@@ -2210,11 +2274,11 @@ class DarkTheme(DefaultTheme):
 
     >>> import pyvista
     >>> from pyvista import themes
-    >>> pyvista.set_plot_theme(themes.DarkTheme())  # doctest:+SKIP
+    >>> pyvista.set_plot_theme(themes.DarkTheme())
 
     Alternatively, set via a string.
 
-    >>> pyvista.set_plot_theme('dark')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('dark')
 
     """
 
@@ -2243,11 +2307,11 @@ class ParaViewTheme(DefaultTheme):
 
     >>> import pyvista
     >>> from pyvista import themes
-    >>> pyvista.set_plot_theme(themes.ParaViewTheme())  # doctest:+SKIP
+    >>> pyvista.set_plot_theme(themes.ParaViewTheme())
 
     Alternatively, set via a string.
 
-    >>> pyvista.set_plot_theme('paraview')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('paraview')
 
     """
 
@@ -2288,11 +2352,11 @@ class DocumentTheme(DefaultTheme):
 
     >>> import pyvista
     >>> from pyvista import themes
-    >>> pyvista.set_plot_theme(themes.DocumentTheme())  # doctest:+SKIP
+    >>> pyvista.set_plot_theme(themes.DocumentTheme())
 
     Alternatively, set via a string.
 
-    >>> pyvista.set_plot_theme('document')  # doctest:+SKIP
+    >>> pyvista.set_plot_theme('document')
 
     """
 
@@ -2313,7 +2377,6 @@ class DocumentTheme(DefaultTheme):
         self.axes.x_color = 'tomato'
         self.axes.y_color = 'seagreen'
         self.axes.z_color = 'blue'
-        self.hidden_line_removal = True
 
 
 class _TestingTheme(DefaultTheme):
