@@ -21,20 +21,40 @@ from . import transformations
 from .xvfb import start_xvfb
 from .reader import (
     get_reader,
+    AVSucdReader,
     BaseReader,
     BinaryMarchingCubesReader,
+    BMPReader,
     BYUReader,
     CGNSReader,
+    DEMReader,
     EnSightReader,
     FacetReader,
+    FluentReader,
+    GLTFReader,
+    HDFReader,
+    HDRReader,
+    JPEGReader,
+    MetaImageReader,
+    MFIXReader,
+    MultiBlockPlot3DReader,
+    NRRDReader,
     OBJReader,
     OpenFOAMReader,
+    POpenFOAMReader,
     Plot3DMetaReader,
     PLYReader,
+    PNGReader,
+    PNMReader,
     PointCellDataSelection,
+    PTSReader,
     PVDDataSet,
     PVDReader,
+    SegYReader,
+    SLCReader,
     STLReader,
+    TecplotReader,
+    TIFFReader,
     TimeReader,
     VTKDataSetReader,
     VTKPDataSetReader,
@@ -47,4 +67,5 @@ from .reader import (
     XMLPolyDataReader,
     XMLStructuredGridReader,
     XMLMultiBlockDataReader,
+    DICOMReader,
 )
