@@ -8,89 +8,7 @@ import numpy as np
 
 import pyvista
 from pyvista import _vtk
-
-READERS = {
-    # Standard dataset readers:
-    '.vtk': _vtk.vtkDataSetReader,
-    '.pvtk': _vtk.lazy_vtkPDataSetReader,
-    '.vti': _vtk.vtkXMLImageDataReader,
-    '.pvti': _vtk.vtkXMLPImageDataReader,
-    '.vtr': _vtk.vtkXMLRectilinearGridReader,
-    '.pvtr': _vtk.vtkXMLPRectilinearGridReader,
-    '.vtu': _vtk.vtkXMLUnstructuredGridReader,
-    '.pvtu': _vtk.vtkXMLPUnstructuredGridReader,
-    '.ply': _vtk.vtkPLYReader,
-    '.obj': _vtk.vtkOBJReader,
-    '.stl': _vtk.vtkSTLReader,
-    '.vtp': _vtk.vtkXMLPolyDataReader,
-    '.vts': _vtk.vtkXMLStructuredGridReader,
-    '.vtm': _vtk.vtkXMLMultiBlockDataReader,
-    '.vtmb': _vtk.vtkXMLMultiBlockDataReader,
-    '.case': _vtk.vtkGenericEnSightReader,
-    # Image formats:
-    '.bmp': _vtk.vtkBMPReader,
-    '.dem': _vtk.vtkDEMReader,
-    '.dcm': _vtk.vtkDICOMImageReader,
-    '.img': _vtk.vtkDICOMImageReader,
-    '.jpeg': _vtk.vtkJPEGReader,
-    '.jpg': _vtk.vtkJPEGReader,
-    '.mha': _vtk.vtkMetaImageReader,
-    '.mhd': _vtk.vtkMetaImageReader,
-    '.nrrd': _vtk.vtkNrrdReader,
-    '.nhdr': _vtk.vtkNrrdReader,
-    '.png': _vtk.vtkPNGReader,
-    '.pnm': _vtk.vtkPNMReader,  # TODO: not tested
-    '.slc': _vtk.vtkSLCReader,
-    '.tiff': _vtk.vtkTIFFReader,
-    '.tif': _vtk.vtkTIFFReader,
-    '.gltf': _vtk.vtkGLTFReader,
-    '.glb': _vtk.vtkGLTFReader,
-    '.hdr': _vtk.vtkHDRReader,
-    # Other formats:
-    '.byu': _vtk.vtkBYUReader,  # TODO: not tested with this extension
-    '.g': _vtk.vtkBYUReader,
-    # '.chemml': _vtk.vtkCMLMoleculeReader, # TODO: not tested
-    # '.cml': _vtk.vtkCMLMoleculeReader, # vtkMolecule is not supported by pyvista
-    # TODO: '.csv': _vtk.vtkCSVReader, # vtkTables are currently not supported
-    '.facet': _vtk.lazy_vtkFacetReader,
-    '.cas': _vtk.vtkFLUENTReader,  # TODO: not tested
-    # '.dat': _vtk.vtkFLUENTReader, # TODO: not working
-    # '.cube': _vtk.vtkGaussianCubeReader, # Contains `atom_types` which are note supported?
-    '.res': _vtk.vtkMFIXReader,  # TODO: not tested
-    '.foam': _vtk.vtkOpenFOAMReader,
-    # '.pdb': _vtk.vtkPDBReader, # Contains `atom_types` which are note supported?
-    '.p3d': _vtk.lazy_vtkPlot3DMetaReader,
-    '.pts': _vtk.vtkPTSReader,
-    # '.particles': _vtk.vtkParticleReader, # TODO: not tested
-    # TODO: '.pht': _vtk.vtkPhasta??????,
-    # TODO: '.vpc': _vtk.vtkVPIC?????,
-    # '.bin': _vtk.lazy_vtkMultiBlockPLOT3DReader,# TODO: non-default routine
-    '.tri': _vtk.vtkMCubesReader,
-    '.inp': _vtk.vtkAVSucdReader,
-}
-
-VTK_MAJOR = _vtk.vtkVersion().GetVTKMajorVersion()
-VTK_MINOR = _vtk.vtkVersion().GetVTKMinorVersion()
-
-if VTK_MAJOR >= 8 and VTK_MINOR >= 2:
-    try:
-        READERS['.sgy'] = _vtk.lazy_vtkSegYReader
-        READERS['.segy'] = _vtk.lazy_vtkSegYReader
-    except AttributeError:
-        pass
-
-
-if VTK_MAJOR >= 9 and VTK_MINOR >= 0:
-    try:
-        READERS['.hdf'] = _vtk.lazy_vtkHDFReader
-    except AttributeError:  # pragma: no cover
-        pass
-
-if VTK_MAJOR >= 9 and VTK_MINOR >= 1:
-    try:
-        READERS['.cgns'] = _vtk.lazy_vtkCGNSReader
-    except AttributeError:  # pragma: no cover
-        pass
+from pyvista.utilities.misc import PyvistaDeprecationWarning
 
 
 def _get_ext_force(filename, force_ext=None):
@@ -106,12 +24,6 @@ def get_ext(filename):
     return ext
 
 
-def get_vtk_reader(filename, force_ext=None):
-    """Get the corresponding reader based on file extension and instantiates it."""
-    ext = _get_ext_force(filename, force_ext=force_ext)
-    return READERS[ext]()  # Get and instantiate the reader
-
-
 def set_vtkwriter_mode(vtk_writer, use_binary=True):
     """Set any vtk writer to write as binary or ascii."""
     if isinstance(vtk_writer, (_vtk.vtkDataWriter, _vtk.vtkPLYWriter, _vtk.vtkSTLWriter)):
@@ -127,80 +39,12 @@ def set_vtkwriter_mode(vtk_writer, use_binary=True):
     return vtk_writer
 
 
-def standard_reader_routine(reader, filename, attrs=None, progress_bar=False):
-    """Use a given reader in the common VTK reading pipeline routine.
-
-    The reader must come from the ``READERS`` mapping.
-
-    Parameters
-    ----------
-    reader : vtkReader
-        Any instantiated VTK reader class
-
-    filename : str
-        The string filename to the data file to read.
-
-    attrs : dict, optional
-        A dictionary of attributes to call on the reader. Keys of
-        dictionary are the attribute/method names and values are the
-        arguments passed to those calls. If you do not have any
-        attributes to call, pass ``None`` as the value.
-
-    progress_bar : bool, optional
-        Optionally show a progress bar.
-
-    """
-    from pyvista.core.filters import _update_alg  # avoid circular import
-
-    observer = pyvista.utilities.errors.Observer()
-    observer.observe(reader)
-
-    if attrs is None:
-        attrs = {}
-    if not isinstance(attrs, dict):
-        raise TypeError('Attributes must be a dictionary of name and arguments.')
-    if filename is not None:
-        try:
-            reader.SetCaseFileName(filename)
-        except AttributeError:
-            reader.SetFileName(filename)
-    # Apply any attributes listed
-    for name, args in attrs.items():
-        attr = getattr(reader, name)
-        if args is not None:
-            if not isinstance(args, (list, tuple)):
-                args = [args]
-            attr(*args)
-        else:
-            attr()
-
-    # Perform the read
-    if filename:
-        msg = f"Reading {os.path.basename(filename)}"
-    else:
-        msg = "Reading file"
-
-    _update_alg(
-        reader,
-        progress_bar=progress_bar,
-        message=msg,
-    )
-
-    # Check reader for errors
-    if observer.has_event_occurred():
-        warnings.warn(
-            f'The VTK reader `{reader.GetClassName()}` raised an error while reading the file.\n'
-            f'\t"{observer.get_message()}"'
-        )
-
-    data = pyvista.wrap(reader.GetOutputDataObject(0))
-    data._post_file_load_processing()
-    return data
-
-
 def read_legacy(filename, progress_bar=False):
     """Use VTK's legacy reader to read a file.
 
+    .. deprecated:: 0.35.0
+        This function is deprecated. Use :func:`pyvsista.read` instead.
+
     This uses ``vtk.vtkDataSetReader`` to read the data.
 
     Parameters
@@ -216,105 +60,34 @@ def read_legacy(filename, progress_bar=False):
     pyvista.DataSet
         Wrapped pyvista mesh.
 
-    Notes
-    -----
-    Normally, you should use :func:`pyvista.read` to read in meshes
-    from file, and this reader will automatically used for ``'.vtk'``
-    and ``'.pvtk'`` files.
-
     Examples
     --------
     Load an example mesh using the legacy reader.
 
     >>> import pyvista
     >>> from pyvista import examples
-    >>> mesh = pyvista.read_legacy(examples.uniformfile)
+    >>> mesh = pyvista.read_legacy(examples.uniformfile)  # doctest:+SKIP
 
     """
+    warnings.warn(
+        "Using read_legacy is deprecated. Use pyvista.read instead", PyvistaDeprecationWarning
+    )
     filename = os.path.abspath(os.path.expanduser(str(filename)))
-    reader = _vtk.vtkDataSetReader()
-    reader.SetFileName(filename)
-    # Ensure all data is fetched with poorly formatted legacy files
-    reader.ReadAllScalarsOn()
-    reader.ReadAllColorScalarsOn()
-    reader.ReadAllNormalsOn()
-    reader.ReadAllTCoordsOn()
-    reader.ReadAllVectorsOn()
-    reader.ReadAllFieldsOn()
-    reader.ReadAllTensorsOn()
-
-    # Perform the read
-    output = standard_reader_routine(reader, None, progress_bar=progress_bar)
-    if output is None:
-        raise RuntimeError('No output when using VTKs legacy reader.')
-    return output
+    return read(filename, progress_bar=progress_bar)
 
 
 def read(filename, attrs=None, force_ext=None, file_format=None, progress_bar=False):
     """Read any file type supported by ``vtk`` or ``meshio``.
 
+    .. deprecated:: 0.35.0
+        Use of `attrs` is deprecated.
+        Use a reader class using :func:`pyvista.get_reader`
+
     Automatically determines the correct reader to use then wraps the
     corresponding mesh as a pyvista object.  Attempts native ``vtk``
     readers first then tries to use ``meshio``.
 
-    Supports the following formats:
-
-    Standard dataset readers:
-
-    * ``'.vtk'``
-    * ``'.pvtk'``
-    * ``'.vti'``
-    * ``'.pvti'``
-    * ``'.vtr'``
-    * ``'.pvtr'``
-    * ``'.vtu'``
-    * ``'.pvtu'``
-    * ``'.ply'``
-    * ``'.obj'``
-    * ``'.stl'``
-    * ``'.vtp'``
-    * ``'.vts'``
-    * ``'.vtm'``
-    * ``'.vtmb'``
-    * ``'.case'``
-
-    Image formats:
-
-    * ``'.bmp'``
-    * ``'.dem'``
-    * ``'.dcm'``
-    * ``'.img'``
-    * ``'.jpeg'``
-    * ``'.jpg'``
-    * ``'.mha'``
-    * ``'.mhd'``
-    * ``'.nrrd'``
-    * ``'.nhdr'``
-    * ``'.png'``
-    * ``'.pnm'``
-    * ``'.slc'``
-    * ``'.tiff'``
-    * ``'.tif'``
-
-    Other formats:
-
-    * ``'.byu'``
-    * ``'.g'``
-    * ``'.p3d'``
-    * ``'.pts'``
-    * ``'.tri'``
-    * ``'.inp'``
-
-    .. note::
-       There is limited support for OpenFoam format files.
-       ``pyvista.read`` will automatically return only the first
-       dataset in a single-element :class:`pyvista.MultiBlock`.  These
-       files include:
-
-       * ``'.facet'``
-       * ``'.cas'``
-       * ``'.res'``
-       * ``'.foam'``
+    See :func:`pyvista.get_reader` for list of formats supported.
 
     .. note::
        See https://github.com/nschloe/meshio for formats supported by
@@ -329,6 +102,7 @@ def read(filename, attrs=None, force_ext=None, file_format=None, progress_bar=Fa
         each file being a separate block in the dataset.
 
     attrs : dict, optional
+        Deprecated. Use a Reader class using :func:`pyvista.get_reader`.
         A dictionary of attributes to call on the reader. Keys of
         dictionary are the attribute/method names and values are the
         arguments passed to those calls. If you do not have any
@@ -384,46 +158,67 @@ def read(filename, attrs=None, force_ext=None, file_format=None, progress_bar=Fa
     if not os.path.isfile(filename):
         raise FileNotFoundError(f'File ({filename}) not found')
 
-    ext = _get_ext_force(filename, force_ext)
-
     # Read file using meshio.read if file_format is present
     if file_format:
         return read_meshio(filename, file_format)
 
-    # From the extension, decide which reader to use
-    if attrs is not None:
-        reader = get_vtk_reader(filename, force_ext=ext)
-        return standard_reader_routine(reader, filename, attrs=attrs, progress_bar=progress_bar)
-    elif ext in ['.e', '.exo']:
+    ext = _get_ext_force(filename, force_ext)
+    if ext in ['.e', '.exo']:
         return read_exodus(filename)
-    elif ext in ['.vtk']:
-        # Attempt to use the legacy reader...
-        return read_legacy(filename, progress_bar=progress_bar)
-    else:
-        # Attempt find a reader in the readers mapping
+
+    try:
+        reader = pyvista.get_reader(filename, force_ext)
+    except ValueError:
+        # if using force_ext, we are explicitly only using vtk readers
+        if force_ext is not None:
+            raise IOError("This file was not able to be automatically read by pvista.")
+        from meshio._exceptions import ReadError
+
         try:
-            reader = get_vtk_reader(filename, force_ext=ext)
-            return standard_reader_routine(reader, filename, progress_bar=progress_bar)
-        except KeyError:
-            # Don't fall back to meshio if using `force_ext`, which is really
-            # just intended to be used with the native PyVista readers
-            if force_ext is not None:
-                from meshio._exceptions import ReadError
+            return read_meshio(filename)
+        except ReadError:
+            raise IOError("This file was not able to be automatically read by pyvista.")
+    else:
+        observer = pyvista.utilities.errors.Observer()
+        observer.observe(reader.reader)
+        if attrs is not None:
+            _apply_attrs_to_reader(reader, attrs)
+        if progress_bar:
+            reader.show_progress()
+        mesh = reader.read()
+        if observer.has_event_occurred():
+            warnings.warn(
+                f"The VTK reader `{reader.reader.GetClassName()}` in pyvista reader `{reader}` raised an error"
+                "while reading the file.\n"
+                f'\t"{observer.get_message()}"'
+            )
+        return mesh
 
-                raise ReadError
-            # Attempt read with meshio
-            try:
-                from meshio._exceptions import ReadError
 
-                try:
-                    return read_meshio(filename)
-                except ReadError:
-                    pass
-            except SyntaxError:
-                # https://github.com/pyvista/pyvista/pull/495
-                pass
+def _apply_attrs_to_reader(reader, attrs):
+    """For a given pyvista reader, call methods according to attrs.
 
-    raise IOError("This file was not able to be automatically read by pyvista.")
+    Parameters
+    ----------
+    reader : pyvista.BaseReader
+        Reader to call methods on.
+
+    attrs : dict
+        Mapping of methods to call on reader.
+
+    """
+    warnings.warn(
+        "attrs use is deprecated.  Use a Reader class for more flexible control",
+        PyvistaDeprecationWarning,
+    )
+    for name, args in attrs.items():
+        attr = getattr(reader.reader, name)
+        if args is not None:
+            if not isinstance(args, (list, tuple)):
+                args = [args]
+            attr(*args)
+        else:
+            attr()
 
 
 def read_texture(filename, attrs=None, progress_bar=False):
@@ -465,8 +260,8 @@ def read_texture(filename, attrs=None, progress_bar=False):
     filename = os.path.abspath(os.path.expanduser(filename))
     try:
         # initialize the reader using the extension to find it
-        reader = get_vtk_reader(filename)
-        image = standard_reader_routine(reader, filename, attrs=attrs, progress_bar=progress_bar)
+
+        image = read(filename, attrs=attrs, progress_bar=progress_bar)
         if image.n_points < 2:
             raise ValueError("Problem reading the image with VTK.")
         return pyvista.Texture(image)
@@ -527,8 +322,7 @@ def read_exodus(
     Examples
     --------
     >>> import pyvista as pv
-    >>> from pyvista import examples
-    >>> data = read_exodus('mymesh.exo')  # doctest:+SKIP
+    >>> data = pv.read_exodus('mymesh.exo')  # doctest:+SKIP
 
     """
     # lazy import here to avoid loading module on import pyvista
@@ -570,6 +364,10 @@ def read_exodus(
 def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None, progress_bar=False):
     """Read a Plot3D grid file (e.g., grid.in) and optional q file(s).
 
+    .. deprecated:: 0.35.0
+        This function is deprecated and will be removed in a future version.
+        Use :class:`pyvista.MultiBlockPlot3DReader`.
+
     Parameters
     ----------
     filename : str
@@ -599,36 +397,20 @@ def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None, progress
         Data read from the file.
 
     """
+    warnings.warn(
+        "Using read_plot3d is deprecated.  Use :class:`pyvista.MultiBlockPlot3DReader`",
+        PyvistaDeprecationWarning,
+    )
+
     filename = _process_filename(filename)
-
-    reader = _vtk.lazy_vtkMultiBlockPLOT3DReader()
-    reader.SetFileName(filename)
-
-    # q_filenames may be a list or a single filename
-    if q_filenames:
-        if isinstance(q_filenames, (str, pathlib.Path)):
-            q_filenames = [q_filenames]
-    q_filenames = [_process_filename(f) for f in q_filenames]
-
-    if hasattr(reader, 'AddFileName'):
-        # AddFileName was added to vtkMultiBlockPLOT3DReader sometime around
-        # VTK 8.2. This method supports reading multiple q files.
-        for q_filename in q_filenames:
-            reader.AddFileName(q_filename)
-    else:
-        # SetQFileName is used to add a single q file to be read, and is still
-        # supported in VTK9.
-        if len(q_filenames) > 0:
-            if len(q_filenames) > 1:
-                raise RuntimeError(
-                    'Reading of multiple q files is not supported with this version of VTK.'
-                )
-            reader.SetQFileName(q_filenames[0])
-
-    attrs = {} if not attrs else attrs
-    attrs['SetAutoDetectFormat'] = auto_detect
-
-    return standard_reader_routine(reader, filename=None, attrs=attrs, progress_bar=progress_bar)
+    reader = pyvista.MultiBlockPlot3DReader(filename)
+    reader.add_q_files(q_filenames)
+    reader.auto_detect_format = auto_detect
+    if attrs is not None:
+        _apply_attrs_to_reader(reader, attrs)
+    if progress_bar:
+        reader.show_progress()
+    return reader.read()
 
 
 def from_meshio(mesh):
