@@ -1,18 +1,22 @@
 """Fine-grained control of reading data files."""
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
+from functools import wraps
 import os
+import pathlib
 from typing import Any, List
 from xml.etree import ElementTree
 
 import pyvista
 from pyvista import _vtk
-from pyvista.utilities import get_ext, wrap
+from pyvista.utilities import abstract_class, wrap
+
+from .fileio import _get_ext_force, _process_filename
 
 HDF_HELP = 'https://kitware.github.io/vtk-examples/site/VTKFileFormats/#hdf-file-formats'
 
 
-def get_reader(filename):
+def get_reader(filename, force_ext=None):
     """Get a reader for fine-grained control of reading data files.
 
     Supported file types and Readers:
@@ -20,22 +24,62 @@ def get_reader(filename):
     +----------------+---------------------------------------------+
     | File Extension | Class                                       |
     +================+=============================================+
-    | ``.cgns``      | :class:`pyvista.CGNSReader`                 |
+    | ``.bmp``       | :class:`pyvista.BMPReader`                  |
+    +----------------+---------------------------------------------+
+    | ``.cas``       | :class:`pyvista.FluentReader`               |
     +----------------+---------------------------------------------+
     | ``.case``      | :class:`pyvista.EnSightReader`              |
     +----------------+---------------------------------------------+
+    | ``.cgns``      | :class:`pyvista.CGNSReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.dat``       | :class:`pyvista.TecplotReader`              |
+    +----------------+---------------------------------------------+
+    | ``.dcm``       | :class:`pyvista.DICOMReader`                |
+    +----------------+---------------------------------------------+
+    | ``.dem``       | :class:`pyvista.DEMReader`                  |
+    +----------------+---------------------------------------------+
     | ``.facet``     | :class:`pyvista.FacetReader`                |
     +----------------+---------------------------------------------+
-    | ``.foam``      | :class:`pyvista.OpenFOAMReader`             |
+    | ``.foam``      | :class:`pyvista.POpenFOAMReader`            |
     +----------------+---------------------------------------------+
     | ``.g``         | :class:`pyvista.BYUReader`                  |
     +----------------+---------------------------------------------+
+    | ``.glb``       | :class:`pyvista.GLTFReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.gltf``      | :class:`pyvista.GLTFReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.hdf``       | :class:`pyvista.HDFReader`                  |
+    +----------------+---------------------------------------------+
+    | ``.img``       | :class:`pyvista.DICOMReader`                |
+    +----------------+---------------------------------------------+
+    | ``.inp``       | :class:`pyvista.AVSucdReader`               |
+    +----------------+---------------------------------------------+
+    | ``.jpg``       | :class:`pyvista.JPEGReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.jpeg``      | :class:`pyvista.JPEGReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.hdr``       | :class:`pyvista.HDRReader`                  |
+    +----------------+---------------------------------------------+
+    | ``.mha``       | :class:`pyvista.MetaImageReader`            |
+    +----------------+---------------------------------------------+
+    | ``.mhd``       | :class:`pyvista.MetaImageReader`            |
+    +----------------+---------------------------------------------+
+    | ``.nhdr``      | :class:`pyvista.NRRDReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.nrrd``      | :class:`pyvista.NRRDReader`                 |
+    +----------------+---------------------------------------------+
     | ``.obj``       | :class:`pyvista.OBJReader`                  |
     +----------------+---------------------------------------------+
     | ``.p3d``       | :class:`pyvista.Plot3DMetaReader`           |
     +----------------+---------------------------------------------+
     | ``.ply``       | :class:`pyvista.PLYReader`                  |
     +----------------+---------------------------------------------+
+    | ``.png``       | :class:`pyvista.PNGReader`                  |
+    +----------------+---------------------------------------------+
+    | ``.pnm``       | :class:`pyvista.PNMReader`                  |
+    +----------------+---------------------------------------------+
+    | ``.pts``       | :class:`pyvista.PTSReader`                  |
+    +----------------+---------------------------------------------+
     | ``.pvd``       | :class:`pyvista.PVDReader`                  |
     +----------------+---------------------------------------------+
     | ``.pvti``      | :class:`pyvista.XMLPImageDataReader`        |
@@ -46,8 +90,20 @@ def get_reader(filename):
     +----------------+---------------------------------------------+
     | ``.pvtu``      | :class:`pyvista.XMLPUnstructuredGridReader` |
     +----------------+---------------------------------------------+
+    | ``.res``       | :class:`pyvista.MFIXReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.segy``      | :class:`pyvista.SegYReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.sgy``       | :class:`pyvista.SegYReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.slc``       | :class:`pyvista.SLCReader`                  |
+    +----------------+---------------------------------------------+
     | ``.stl``       | :class:`pyvista.STLReader`                  |
     +----------------+---------------------------------------------+
+    | ``.tif``       | :class:`pyvista.TIFFReader`                 |
+    +----------------+---------------------------------------------+
+    | ``.tiff``      | :class:`pyvista.TIFFReader`                 |
+    +----------------+---------------------------------------------+
     | ``.tri``       | :class:`pyvista.BinaryMarchingCubesReader`  |
     +----------------+---------------------------------------------+
     | ``.vti``       | :class:`pyvista.XMLImageDataReader`         |
@@ -72,6 +128,9 @@ def get_reader(filename):
     filename : str
         The string path to the file to read.
 
+    force_ext : str, optional
+        An extension to force a specific reader to be chosen.
+
     Returns
     -------
     pyvista.BaseReader
@@ -93,7 +152,7 @@ def get_reader(filename):
     >>> mesh.plot(color='tan')
 
     """
-    ext = get_ext(filename)
+    ext = _get_ext_force(filename, force_ext)
 
     try:
         Reader = CLASS_READERS[ext]
@@ -103,6 +162,7 @@ def get_reader(filename):
     return Reader(filename)
 
 
+@abstract_class
 class BaseReader:
     """The Base Reader class.
 
@@ -113,39 +173,61 @@ class BaseReader:
 
     Parameters
     ----------
-    filename : str
+    path : str
         Path of the file to read.
     """
 
     _class_reader: Any = None
 
-    def __init__(self, filename):
-        """Initialize Reader by setting filename."""
+    def __init__(self, path):
+        """Initialize Reader by setting path."""
         self._reader = self._class_reader()
-        self.filename = filename
-        self._set_filename(filename)
+        self._filename = None
         self._progress_bar = False
         self._progress_msg = None
+        self.__directory = None
+        self._set_defaults()
+        self.path = path
+        self._set_defaults_post()
 
     def __repr__(self):
         """Representation of a Reader object."""
-        return f"{self.__class__.__name__}('{self.filename}')"
+        return f"{self.__class__.__name__}('{self.path}')"
 
     def show_progress(self, msg=None):
-        """Show a progress bar.
+        """Show a progress bar when loading the file.
 
         Parameters
         ----------
         msg : str, optional
-            Progress bar message. Defaults to "Reading <file base name>"
+            Progress bar message. Defaults to ``"Reading <file base name>"``.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.show_progress()
+
         """
         self._progress_bar = True
         if msg is None:
-            msg = f"Reading {os.path.basename(self.filename)}"
+            msg = f"Reading {os.path.basename(self.path)}"
         self._progress_msg = msg
 
     def hide_progress(self):
-        """Hide the progress bar."""
+        """Hide the progress bar when loading the file.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.hide_progress()
+
+        """
         self._progress_bar = False
 
     @property
@@ -162,11 +244,46 @@ class BaseReader:
             raise NotImplementedError
         return self._reader
 
+    @property
+    def path(self) -> str:
+        """Return or set the filename or directory of the reader.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_human(load=False)
+        >>> reader = pyvista.XMLPolyDataReader(filename)
+        >>> reader.path  # doctest:+SKIP
+        '/home/user/.local/share/pyvista/examples/Human.vtp'
+
+        """
+        if self._filename is not None:
+            return self._filename
+        return self.__directory
+
+    @path.setter
+    def path(self, path: str):
+        if os.path.isdir(path):
+            self._set_directory(path)
+        elif os.path.isfile(path):
+            self._set_filename(path)
+        else:
+            raise FileNotFoundError(f"Path '{path}' is invalid or does not exist.")
+
+    def _set_directory(self, directory):
+        """Set directory and update reader."""
+        self._filename = None
+        self.__directory = directory
+        self.reader.SetDirectoryName(directory)
+        self._update_information()
+
     def _set_filename(self, filename):
         """Set filename and update reader."""
         # Private method since changing file type requires a
         # different subclass.
-        self.filename = filename
+        self.__directory = None
+        self._filename = filename
         self.reader.SetFileName(filename)
         self._update_information()
 
@@ -190,6 +307,14 @@ class BaseReader:
     def _update_information(self):
         self.reader.UpdateInformation()
 
+    def _set_defaults(self):
+        """Set defaults on reader, if needed."""
+        pass
+
+    def _set_defaults_post(self):
+        """Set defaults on reader post setting file, if needed."""
+        pass
+
 
 class PointCellDataSelection:
     """Mixin for readers that support data array selections.
@@ -569,6 +694,8 @@ class XMLMultiBlockDataReader(BaseReader, PointCellDataSelection):
 
 
 # skip pydocstyle D102 check since docstring is taken from TimeReader
+
+
 class EnSightReader(BaseReader, PointCellDataSelection, TimeReader):
     """EnSight Reader for .case files.
 
@@ -592,7 +719,7 @@ class EnSightReader(BaseReader, PointCellDataSelection, TimeReader):
         """Set filename and update reader."""
         # Private method since changing file type requires a
         # different subclass.
-        self.filename = filename
+        self._filename = filename
         self.reader.SetCaseFileName(filename)
         self._update_information()
 
@@ -620,18 +747,16 @@ class EnSightReader(BaseReader, PointCellDataSelection, TimeReader):
 
 # skip pydocstyle D102 check since docstring is taken from TimeReader
 class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
-    """OpenFOAM Reader for .foam files."""
+    """OpenFOAM Reader for .foam files.
+
+    By default, pyvista enables all patch arrays.  This is a deviation
+    from the vtk default.
+
+    """
 
     _class_reader = _vtk.vtkOpenFOAMReader
 
-    def __init__(self, filename):
-        """Initialize OpenFOAMReader.
-
-        By default, pyvista enables all patch arrays.  This is a deviation
-        from the vtk default.
-
-        """
-        super().__init__(filename)
+    def _set_defaults_post(self):
         self.enable_all_patch_arrays()
 
     @property
@@ -654,12 +779,73 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
     def set_active_time_value(self, time_value):  # noqa: D102
         if time_value not in self.time_values:
             raise ValueError(
-                f"Not a valid time {time_value} from available time values: {self.reader_time_values}"
+                f"Not a valid time {time_value} from available time values: {self.time_values}"
             )
-        self.reader.SetTimeValue(time_value)
+        self.reader.UpdateTimeStep(time_value)
 
     def set_active_time_point(self, time_point):  # noqa: D102
-        self.reader.SetTimeValue(self.time_point_value(time_point))
+        self.reader.UpdateTimeStep(self.time_point_value(time_point))
+
+    @property
+    def decompose_polyhedra(self):
+        """Whether polyhedra are to be decomposed when read.
+
+        Returns
+        -------
+        bool
+            If ``True``, decompose polyhedra into tetrahedra and pyramids.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.decompose_polyhedra = False
+        >>> reader.decompose_polyhedra
+        False
+
+        """
+        return bool(self.reader.GetDecomposePolyhedra())
+
+    @decompose_polyhedra.setter
+    def decompose_polyhedra(self, value):
+        if value:
+            self.reader.DecomposePolyhedraOn()
+        else:
+            self.reader.DecomposePolyhedraOff()
+
+    @property
+    def skip_zero_time(self):
+        """Indicate whether or not to ignore the '/0' time directory.
+
+        Returns
+        -------
+        bool
+            If ``True``, ignore the '/0' time directory.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.skip_zero_time = False
+        >>> reader.skip_zero_time
+        False
+
+        """
+        return bool(self.reader.GetSkipZeroTime())
+
+    @skip_zero_time.setter
+    def skip_zero_time(self, value):
+        if value:
+            self.reader.SkipZeroTimeOn()
+        else:
+            self.reader.SkipZeroTimeOff()
+
+        self._update_information()
+        self.reader.SetRefresh()
 
     @property
     def cell_to_point_creation(self):
@@ -857,6 +1043,55 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
         return {name: self.patch_array_status(name) for name in self.patch_array_names}
 
 
+class POpenFOAMReader(OpenFOAMReader):
+    """Parallel OpenFOAM Reader for .foam files.
+
+    Can read parallel-decomposed mesh information and time dependent data.
+    This reader can be used for serial generated data,
+    parallel reconstructed data, and decomposed data.
+    """
+
+    _class_reader = staticmethod(_vtk.lazy_vtkPOpenFOAMReader)
+
+    @property
+    def case_type(self):
+        """Indicate whether decomposed mesh or reconstructed mesh should be read.
+
+        Returns
+        -------
+        str
+            If ``'reconstructed'``, reconstructed mesh should be read.
+            If ``'decomposed'``, decomposed mesh should be read.
+
+        Raises
+        ------
+        ValueError
+            If the value is not in ['reconstructed', 'decomposed']
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.POpenFOAMReader(filename)
+        >>> reader.case_type = 'reconstructed'
+        >>> reader.case_type
+        'reconstructed'
+        """
+        return 'reconstructed' if self.reader.GetCaseType() else 'decomposed'
+
+    @case_type.setter
+    def case_type(self, value):
+        if value == 'reconstructed':
+            self.reader.SetCaseType(1)
+        elif value == 'decomposed':
+            self.reader.SetCaseType(0)
+        else:
+            raise ValueError(f"Unknown case type '{value}'.")
+
+        self._update_information()
+
+
 class PLYReader(BaseReader):
     """PLY Reader for reading .ply files.
 
@@ -914,14 +1149,31 @@ class STLReader(BaseReader):
     _class_reader = _vtk.vtkSTLReader
 
 
+class TecplotReader(BaseReader):
+    """Tecplot Reader for ascii .dat files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_tecplot_ascii(load=False)
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh[0].plot()
+
+    """
+
+    _class_reader = _vtk.vtkTecplotReader
+
+
 class VTKDataSetReader(BaseReader):
     """VTK Data Set Reader for .vtk files.
 
     Notes
     -----
-    This reader calls `ReadAllScalarsOn`, `ReadAllColorScalarsOn`,
-    `ReadAllNormalsOn`, `ReadAllTCoordsOn`, `ReadAllVectorsOn`,
-    and `ReadAllFieldsOn` on the underlying `vtkDataSetReader`.
+    This reader calls ``ReadAllScalarsOn``, ``ReadAllColorScalarsOn``,
+    ``ReadAllNormalsOn``, ``ReadAllTCoordsOn``, ``ReadAllVectorsOn``,
+    and ``ReadAllFieldsOn`` on the underlying ``vtkDataSetReader``.
 
     Examples
     --------
@@ -939,10 +1191,7 @@ class VTKDataSetReader(BaseReader):
 
     _class_reader = _vtk.vtkDataSetReader
 
-    def __init__(self, filename):
-        """Initialize VTKDataSetReader with filename."""
-        super().__init__(filename)
-        # Provide consistency with defaults in pyvista.read
+    def _set_defaults_post(self):
         self.reader.ReadAllScalarsOn()
         self.reader.ReadAllColorScalarsOn()
         self.reader.ReadAllNormalsOn()
@@ -1002,6 +1251,54 @@ class Plot3DMetaReader(BaseReader):
     _class_reader = staticmethod(_vtk.lazy_vtkPlot3DMetaReader)
 
 
+class MultiBlockPlot3DReader(BaseReader):
+    """MultiBlock Plot3D Reader."""
+
+    _class_reader = staticmethod(_vtk.lazy_vtkMultiBlockPLOT3DReader)
+
+    def _set_defaults(self):
+        self.auto_detect_format = True
+
+    def add_q_files(self, files):
+        """Add q file(s).
+
+        Parameters
+        ----------
+        files : str or Iterable(str)
+            Solution file or files to add.
+
+        """
+        # files may be a list or a single filename
+        if files:
+            if isinstance(files, (str, pathlib.Path)):
+                files = [files]
+        files = [_process_filename(f) for f in files]
+
+        if hasattr(self.reader, 'AddFileName'):
+            # AddFileName was added to vtkMultiBlockPLOT3DReader sometime around
+            # VTK 8.2. This method supports reading multiple q files.
+            for q_filename in files:
+                self.reader.AddFileName(q_filename)
+        else:
+            # SetQFileName is used to add a single q file to be read, and is still
+            # supported in VTK9.
+            if len(files) > 0:
+                if len(files) > 1:
+                    raise RuntimeError(
+                        'Reading of multiple q files is not supported with this version of VTK.'
+                    )
+                self.reader.SetQFileName(files[0])
+
+    @property
+    def auto_detect_format(self):
+        """Whether to try to automatically detect format such as byte order, etc."""
+        return bool(self.reader.GetAutoDetectFormat())
+
+    @auto_detect_format.setter
+    def auto_detect_format(self, value):
+        self.reader.SetAutoDetectFormat(value)
+
+
 class CGNSReader(BaseReader, PointCellDataSelection):
     """CGNS Reader for .cgns files.
 
@@ -1031,20 +1328,18 @@ class CGNSReader(BaseReader, PointCellDataSelection):
     Active Texture  : None
     Active Normals  : None
     Contains arrays :
-        Density                 float64  (2928,)
-        Momentum                float64  (2928, 3)            VECTORS
-        EnergyStagnationDensity float64  (2928,)
-        ViscosityEddy           float64  (2928,)
-        TurbulentDistance       float64  (2928,)
-        TurbulentSANuTilde      float64  (2928,)
+        Density                 float64    (2928,)
+        Momentum                float64    (2928, 3)            VECTORS
+        EnergyStagnationDensity float64    (2928,)
+        ViscosityEddy           float64    (2928,)
+        TurbulentDistance       float64    (2928,)
+        TurbulentSANuTilde      float64    (2928,)
 
     """
 
     _class_reader = staticmethod(_vtk.lazy_vtkCGNSReader)
 
-    def __init__(self, filename: str):
-        """Initialize CGNSReader with filename."""
-        super().__init__(filename)
+    def _set_defaults_post(self):
         self.enable_all_point_arrays()
         self.enable_all_cell_arrays()
         self.load_boundary_patch = True
@@ -1326,7 +1621,7 @@ class PVDDataSet:
 
     time: float
     part: int
-    filename: str
+    path: str
     group: str
 
 
@@ -1355,8 +1650,7 @@ class PVDReader(BaseReader, TimeReader):
     def __init__(self, filename):
         """Initialize PVD file reader."""
         self._reader = None
-        self.filename = filename
-        self._directory = None
+        self.__directory = None
         self._datasets = []
         self._active_datasets = []
         self._active_readers = []
@@ -1409,8 +1703,8 @@ class PVDReader(BaseReader, TimeReader):
 
     def _set_filename(self, filename):
         """Set filename and update reader."""
-        self.filename = filename
-        self._directory = os.path.dirname(filename)
+        self._filename = filename
+        self.__directory = os.path.join(os.path.dirname(filename))
         self._datasets = None
         self._active_datasets = None
         self._update_information()
@@ -1434,9 +1728,9 @@ class PVDReader(BaseReader, TimeReader):
 
     def _parse_file(self):
         """Parse PVD file."""
-        if self.filename is None:
+        if self.path is None:
             raise ValueError("Filename must be set")
-        tree = ElementTree.parse(self.filename)
+        tree = ElementTree.parse(self.path)
         root = tree.getroot()
         dataset_elements = root[0].findall("DataSet")
         datasets = []
@@ -1474,7 +1768,7 @@ class PVDReader(BaseReader, TimeReader):
     def set_active_time_value(self, time_value):  # noqa: D102
         self._active_datasets = [dataset for dataset in self.datasets if dataset.time == time_value]
         self._active_readers = [
-            get_reader(os.path.join(self._directory, dataset.filename))
+            get_reader(os.path.join(self.__directory, dataset.path))
             for dataset in self.active_datasets
         ]
 
@@ -1482,29 +1776,357 @@ class PVDReader(BaseReader, TimeReader):
         self.set_active_time_value(self.time_values[time_point])
 
 
+class DICOMReader(BaseReader):
+    """DICOM Reader for reading ``.dcm`` files.
+
+    This reader reads a single file or a path containing a several ``.dcm``
+    files (DICOM stack).
+
+    Parameters
+    ----------
+    path : str
+        Path to the single DICOM (``.dcm``) file to be opened or the directory
+        containing a stack of DICOM files.
+
+    Examples
+    --------
+    Read a DICOM stack.
+
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> path = examples.download_dicom_stack(load=False)
+    >>> reader = pyvista.DICOMReader(path)
+    >>> dataset = reader.read()
+    >>> dataset.plot(volume=True, zoom=3, show_scalar_bar=False)
+
+    """
+
+    _class_reader = _vtk.vtkDICOMImageReader
+
+
+class BMPReader(BaseReader):
+    """BMP Reader for .bmp files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_masonry_texture(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'masonry.bmp'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkBMPReader
+
+
+class DEMReader(BaseReader):
+    """DEM Reader for .dem files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_st_helens(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'SainteHelens.dem'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkDEMReader
+
+
+class JPEGReader(BaseReader):
+    """JPEG Reader for .jpeg and .jpg files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_mars_jpg()
+    >>> filename.split("/")[-1]  # omit the path
+    'mars.jpg'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkJPEGReader
+
+
+class MetaImageReader(BaseReader):
+    """Meta Image Reader for .mha and .mhd files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_chest(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'ChestCT-SHORT.mha'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkMetaImageReader
+
+
+class NRRDReader(BaseReader):
+    """NRRDReader for .nrrd and .nhdr files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_beach(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'beach.nrrd'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkNrrdReader
+
+
+class PNGReader(BaseReader):
+    """PNGReader for .png files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_vtk_logo(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'vtk.png'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkPNGReader
+
+
+class PNMReader(BaseReader):
+    """PNMReader for .pnm files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_gourds_pnm(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'Gourds.pnm'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkPNMReader
+
+
+class SLCReader(BaseReader):
+    """SLCReader for .slc files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_knee_full(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'vw_knee.slc'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkSLCReader
+
+
+class TIFFReader(BaseReader):
+    """TIFFReader for .tif and .tiff files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_crater_imagery(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'BJ34_GeoTifv1-04_crater_clip.tif'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkTIFFReader
+
+
+class HDRReader(BaseReader):
+    """HDRReader for .hdr files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_parched_canal_4k(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'parched_canal_4k.hdr'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = _vtk.vtkHDRReader
+
+
+class PTSReader(BaseReader):
+    """PTSReader for .pts files."""
+
+    _class_reader = _vtk.vtkPTSReader
+
+
+class AVSucdReader(BaseReader):
+    """AVSucdReader for .inp files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_cells_nd(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'cellsnd.ascii.inp'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot(cpos="xy")
+
+    """
+
+    _class_reader = _vtk.vtkAVSucdReader
+
+
+class HDFReader(BaseReader):
+    """HDFReader for .hdf files.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_can_crushed_hdf(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'can-vtu.hdf'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot()
+
+    """
+
+    _class_reader = staticmethod(_vtk.lazy_vtkHDFReader)
+
+    @wraps(BaseReader.read)
+    def read(self):
+        """Wrap the base reader to handle the vtk 9.1 --> 9.2 change."""
+        try:
+            with pyvista.VtkErrorCatcher(raise_errors=True):
+                return super().read()
+        except RuntimeError as err:  # pragma: no cover
+            if "Can't find the `Type` attribute." in str(err):
+                raise RuntimeError(
+                    f'{self.path} is missing the Type attribute. '
+                    'The VTKHDF format has changed as of 9.2.0, '
+                    f'see {HDF_HELP} for more details.'
+                )
+            else:
+                raise err
+
+
+class GLTFReader(BaseReader):
+    """GLTFeader for .gltf and .glb files."""
+
+    _class_reader = _vtk.vtkGLTFReader
+
+
+class FluentReader(BaseReader):
+    """FluentReader for .cas files."""
+
+    _class_reader = _vtk.vtkFLUENTReader
+
+
+class MFIXReader(BaseReader):
+    """MFIXReader for .res files."""
+
+    _class_reader = _vtk.vtkMFIXReader
+
+
+class SegYReader(BaseReader):
+    """SegYReader for .sgy and .segy files."""
+
+    _class_reader = staticmethod(_vtk.lazy_vtkSegYReader)
+
+
 CLASS_READERS = {
     # Standard dataset readers:
+    '.bmp': BMPReader,
+    '.cas': FluentReader,
+    '.case': EnSightReader,
     '.cgns': CGNSReader,
-    '.vti': XMLImageDataReader,
+    '.dat': TecplotReader,
+    '.dcm': DICOMReader,
+    '.dem': DEMReader,
+    '.facet': FacetReader,
+    '.foam': POpenFOAMReader,
+    '.g': BYUReader,
+    '.glb': GLTFReader,
+    '.gltf': GLTFReader,
+    '.img': DICOMReader,
+    '.inp': AVSucdReader,
+    '.jpg': JPEGReader,
+    '.jpeg': JPEGReader,
+    '.hdf': HDFReader,
+    '.hdr': HDRReader,
+    '.mha': MetaImageReader,
+    '.mhd': MetaImageReader,
+    '.nhdr': NRRDReader,
+    '.nrrd': NRRDReader,
+    '.obj': OBJReader,
+    '.p3d': Plot3DMetaReader,
+    '.ply': PLYReader,
+    '.png': PNGReader,
+    '.pnm': PNMReader,
+    '.pts': PTSReader,
+    '.pvd': PVDReader,
     '.pvti': XMLPImageDataReader,
-    '.vtr': XMLRectilinearGridReader,
+    '.pvtk': VTKPDataSetReader,
     '.pvtr': XMLPRectilinearGridReader,
-    '.vtu': XMLUnstructuredGridReader,
     '.pvtu': XMLPUnstructuredGridReader,
-    '.vtp': XMLPolyDataReader,
-    '.vts': XMLStructuredGridReader,
+    '.res': MFIXReader,
+    '.segy': SegYReader,
+    '.sgy': SegYReader,
+    '.slc': SLCReader,
+    '.stl': STLReader,
+    '.tif': TIFFReader,
+    '.tiff': TIFFReader,
+    '.tri': BinaryMarchingCubesReader,
+    '.vti': XMLImageDataReader,
+    '.vtk': VTKDataSetReader,
     '.vtm': XMLMultiBlockDataReader,
     '.vtmb': XMLMultiBlockDataReader,
-    '.case': EnSightReader,
-    '.foam': OpenFOAMReader,
-    '.ply': PLYReader,
-    '.obj': OBJReader,
-    '.stl': STLReader,
-    '.vtk': VTKDataSetReader,
-    '.pvtk': VTKPDataSetReader,
-    '.g': BYUReader,
-    '.facet': FacetReader,
-    '.p3d': Plot3DMetaReader,
-    '.tri': BinaryMarchingCubesReader,
-    '.pvd': PVDReader,
+    '.vtp': XMLPolyDataReader,
+    '.vtr': XMLRectilinearGridReader,
+    '.vts': XMLStructuredGridReader,
+    '.vtu': XMLUnstructuredGridReader,
 }
